package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MapBean;
import com.bonus.canteen.core.menu.dto.MenuDishesDTO;
import com.bonus.canteen.core.menu.service.IMenuDishesService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.menu.domain.MenuDishes;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品信息Controller
 *
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "菜品信息接口")
@RestController
@RequestMapping("/menu_dishes")
public class MenuDishesController extends BaseController {
    @Autowired
    private IMenuDishesService menuDishesService;

    /**
     * 查询菜品信息列表
     */
    @ApiOperation(value = "查询菜品信息列表")
    //@RequiresPermissions("menu:dishes:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuDishes menuDishes) {
        startPage();
        List<MenuDishes> list = menuDishesService.selectMenuDishesList(menuDishes);
        return getDataTable(list);
    }

    /**
     * 导出菜品信息列表
     */
    @ApiOperation(value = "导出菜品信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:export")
    @SysLog(title = "菜品信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuDishes menuDishes) {
        List<MenuDishes> list = menuDishesService.selectMenuDishesList(menuDishes);
        ExcelUtil<MenuDishes> util = new ExcelUtil<MenuDishes>(MenuDishes.class);
        util.exportExcel(response, list, "菜品信息数据");
    }

    /**
     * 获取菜品信息详细信息
     */
    @ApiOperation(value = "获取菜品信息详细信息")
    //@RequiresPermissions("menu:dishes:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuDishesService.selectMenuDishesById(id));
    }
    @ApiOperation(value = "获取菜品信息详细信息")
    //@RequiresPermissions("menu:dishes:query")
    @PostMapping(value = "/getDishesType")
    public AjaxResult getDishesType(@RequestBody MapBean mapBean) {
        return success(menuDishesService.getDishesType(mapBean));
    }



    /**
     * 新增菜品信息
     */
    @ApiOperation(value = "新增菜品信息-已弃用")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品信息")
    @PostMapping
    public AjaxResult add(@RequestBody MenuDishes menuDishes) {
        try {
            return toAjax(menuDishesService.insertMenuDishes(menuDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }
    //MenuDishesDTO

    @ApiOperation(value = "新增菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品信息")
    @PostMapping("/addMenuDishes")
    public AjaxResult addMenuDishes(@RequestBody MenuDishesDTO menuDishesDTO) {
        try {
            return toAjax(menuDishesService.addMenuDishes(menuDishesDTO));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改菜品信息
     */
    @ApiOperation(value = "修改菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:edit")
    @SysLog(title = "菜品信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuDishes menuDishes) {
        try {
            return toAjax(menuDishesService.updateMenuDishes(menuDishes));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除菜品信息
     */
    @ApiOperation(value = "删除菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:remove")
    @SysLog(title = "菜品信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品信息")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuDishesService.deleteMenuDishesByIds(ids));
    }
}
